Komm
====

.. image:: https://travis-ci.org/rwnobrega/komm.svg?branch=master
   :target: https://travis-ci.org/rwnobrega/komm/
   :alt: Build status
.. image:: https://readthedocs.org/projects/komm/badge/?version=latest
   :target: https://komm.readthedocs.io/en/latest/
   :alt: Documentation status
.. image:: https://badge.fury.io/py/komm.svg
   :target: https://pypi.org/project/komm/
   :alt: PyPI page
.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/rwnobrega/komm/master?filepath=demo
   :alt: Binder

Welcome to **Komm**'s development page!

**Komm** is an open-source library for Python 3 providing tools for analysis and simulation of analog and digital communication systems. This project is inspired by---but is not meant to be compatible with---the MATLAB® `Communications System Toolbox™ <https://www.mathworks.com/help/comm/>`_. Other sources of inspiration include `GNU Radio <https://gnuradio.org/>`_, `CommPy <http://veeresht.info/CommPy/>`_, and `SageMath <https://www.sagemath.org/>`_. **Komm** is licensed under the `GNU General Public License v3.0 <https://www.gnu.org/licenses/gpl-3.0.en.html>`_.

For library reference, please check the project's `documentation page at Read the Docs <http://komm.readthedocs.io/>`_.
 
This software is still under development. Contributions are very welcome!

Installation
------------

Before you start, make sure you have `Python <https://www.python.org/>`_ (version 3.4 or later), `NumPy <https://www.numpy.org/>`_, and `SciPy <https://www.scipy.org/>`_ installed.

Using pip
~~~~~~~~~

.. code-block:: bash

   $ sudo pip3 install komm

From source
~~~~~~~~~~~

.. code-block:: bash

   $ git clone https://github.com/rwnobrega/komm
   $ cd komm/
   $ sudo python3 setup.py install
